@@ -83,6 +83,26 @@ def get_inputs_from_cli(args):
     parser.add_argument(
         "-t",
         "--tool",
+        choices=[
+            "nuclei",
+            "bearer",
+            "checkov",
+            "kics",
+            "kubescape",
+            "trufflehog",
+            "gitleaks",
+            "prisma",
+            "trivy",
+            "xray",
+            "dependency_check",
+        ],
+        type=str,
+        required=False,
+        help="Tool to execute according to the module",
+    )
+    parser.add_argument(
+        "-m",
+        "--module",
         choices=[
             "engine_iac",
             "engine_dast",
@@ -94,7 +114,7 @@ def get_inputs_from_cli(args):
         ],
         type=str,
         required=True,
-        help="Tool to execute",
+        help="Module to execute",
     )
     parser.add_argument(
         "-fp",
@@ -176,12 +196,32 @@ def get_inputs_from_cli(args):
         help="File path containing the configuration, structured according to the documentation, \
         for the API or web application to be scanned by the DAST tool."
     )
+
+    TOOLS = {
+        "engine_iac": ["checkov", "kics", "kubescape"],
+        "engine_secret": ["trufflehog", "gitleaks"],
+        "engine_container": ["prisma", "trivy"],
+        "engine_dependencies": ["xray", "dependency_check"],
+        "engine_code": ["bearer"],
+        "engine_dast": ["nuclei"],
+        "engine_risk": None,
+    }
+
     args = parser.parse_args()
+
+    if args.module in TOOLS and args.tool:
+        allowed_tools = TOOLS[args.module]
+        if allowed_tools is None:
+            parser.error(f"The tool flag should not be used with module {args.module}")
+        elif allowed_tools and (args.tool not in allowed_tools):
+            parser.error(f"Invalid value for tool. Allowed values for the provided module {args.module} are: {', '.join(allowed_tools)}")
+
     return {
         "platform_devops": args.platform_devops,
         "remote_config_repo": args.remote_config_repo,
         "remote_config_branch": args.remote_config_branch,
         "tool": args.tool,
+        "module": args.module,
         "folder_path": args.folder_path,
         "platform": args.platform,
         "use_secrets_manager": args.use_secrets_manager,
